# Info Array

This document outlines the content of the `info` array available inside `.dat` files (see [../src/irsol_data_pipeline/io/dat/importer.py](`.dat` reader implementation)).
The typical content of the array, when parsed into a json format of key-value pairs, looks like this:
```json
{
  "calibration.description": "r12, r22, r32, r33",
  "calibration.file": "/global/data1/zimpol/2025/251111/raw/cal5886_m2.z3bd",
  "calibration.software": "Z3calibrate.pro (24.09.2024)",
  "calibration.status": "yes",
  "flatfield.status": "no",
  "global.mean": "      59005.9 -2.59019e-05 -2.27992e-05   0.00602865",
  "global.noise": "      440.579  0.000601946  0.000599725  0.000571274",
  "measurement.TCU.mode": "1",
  "measurement.TCU.positions": "0.0 45.0 90.0 135.0 22.5 67.5 112.5 157.5 ",
  "measurement.TCU.retarder.name": "HWP_550",
  "measurement.TCU.retarder.wl_parameter": "0.50 549.99 12766003. 1",
  "measurement.camera.CCD": "03262-21-09",
  "measurement.camera.identity": "CAM2",
  "measurement.camera.position": "0 560 0 1240",
  "measurement.camera.temperature": "-15.02",
  "measurement.datetime": "2025-11-11T09:43:16+01:00",
  "measurement.datetime.end": "2025-11-11T09:44:42+01:00",
  "measurement.derotator.coordinate_system": "1",
  "measurement.derotator.offset": "0",
  "measurement.derotator.position_angle": "45.0",
  "measurement.file": "/global/data1/zimpol/2025/251111/raw/5886_m13.z3bd",
  "measurement.guiding.status": "2",
  "measurement.id": "1762850596",
  "measurement.image.type": "Spectrum",
  "measurement.image.type_x": "spectral",
  "measurement.image.type_y": "spatial",
  "measurement.images": "16 16 16 16 ",
  "measurement.instrument": "ZIMPOL3",
  "measurement.instrument.post-focus": "Spectrograph",
  "measurement.integration time": "0.1",
  "measurement.limbguider.status": "0",
  "measurement.modulator type": "PEM",
  "measurement.name": "5886_m13",
  "measurement.observer": "afb",
  "measurement.pig.intensity": "115",
  "measurement.polcomp.status": "0",
  "measurement.project": "flare5884",
  "measurement.sequence.length": "2",
  "measurement.solar_disc.coordinates": "344.5 447.0",
  "measurement.spectrograph.alpha": "27.73",
  "measurement.spectrograph.grtwl": "5886.139",
  "measurement.spectrograph.order": "5",
  "measurement.spectrograph.slit": "0.06",
  "measurement.stokes vector": "IQUV",
  "measurement.sub-sequence.length": "4",
  "measurement.sub-sequence.name": "TCU0Q TCU0U TCU1Q TCU1U ",
  "measurement.sun.p0": "22.3",
  "measurement.telescope name": "Gregory IRSOL",
  "measurement.type": "SCIENCE",
  "measurement.wavelength": "5886",
  "reduction.TCU.method": "       0",
  "reduction.dcfit": "poly_fit 7",
  "reduction.demodulation matrix": "  1  1  1  1  0  0  0  0 -1  1  1 -1  1  1 -1 -1",
  "reduction.file": "5886_m13.z3bd",
  "reduction.file.dc.used": "/global/data1/zimpol/2025/251111/reduced/dark00100_m4.sav",
  "reduction.mode": "two phase subtraction",
  "reduction.number of files": "1",
  "reduction.order of rows": " 0 1 2 3",
  "reduction.outfname": "5886_m13.dat",
  "reduction.pixels replaced": "        3294           3           1          30",
  "reduction.software": "Z3reduce.pro (v06.05.2020)",
  "reduction.status": "yes"
}
```
